@@ -15,8 +15,8 @@ from notice.models import NoticeStore, ReceiverTag
 from notice.response import AuthFailed, NotFound, ValidationFailed, ValidationFailedDetailEnum
 
 
-def get_page_notice(receiver_id, page, size, **kwargs):
-    allowed_notice_type_ids, allowed_receiver_type_ids = NOTICE_ALLOWED_TYPED_CLASS(receiver_id=receiver_id, **kwargs).judge()
+def get_page_notice(receiver_id, page, size, judge_kwargs: dict =dict()):
+    allowed_notice_type_ids, allowed_receiver_type_ids = NOTICE_ALLOWED_TYPED_CLASS(receiver_id=receiver_id, judge_kwargs=judge_kwargs).judge()
     if not allowed_notice_type_ids or not allowed_receiver_type_ids:
         return JsonResponse(data={
             'total': 0,
@@ -28,7 +28,7 @@ def get_page_notice(receiver_id, page, size, **kwargs):
     filter_params = {
         'is_draft': False,
         'publish_at__lte': timezone.now(),
-        'receiver_type_id__in': allowed_receiver_type_ids,
+        'receiver_type_ids__overlap': allowed_receiver_type_ids,
         'notice_type_id__in': allowed_notice_type_ids
     }
     total = NoticeStore.objects.filter(**filter_params).count()
@@ -75,15 +75,15 @@ def list_notice(request: HttpRequest):
     return get_page_notice(request.user.pk, page, size)
 
 
-def retrieve_notice(receiver_id, pk, **kwargs):
-    allowed_notice_type_ids, allowed_receiver_type_ids = NOTICE_ALLOWED_TYPED_CLASS(receiver_id, **kwargs).judge()
+def retrieve_notice(receiver_id, pk, judge_kwargs: dict = dict()):
+    allowed_notice_type_ids, allowed_receiver_type_ids = NOTICE_ALLOWED_TYPED_CLASS(receiver_id, judge_kwargs).judge()
     if not allowed_notice_type_ids or not allowed_receiver_type_ids:
         return NotFound()
 
     filter_params = {
         'is_draft': False,
         'publish_at__lte': timezone.now(),
-        'receiver_type_id__in': allowed_receiver_type_ids,
+        'receiver_type_ids__overlap': allowed_receiver_type_ids,
         'notice_type_id__in': allowed_notice_type_ids,
         'pk': pk
     }
